require 'json'

# @author Frederik  Feys
class JSONThermostat
  attr_accessor :current_value
  attr_accessor :wanted_value
  attr_accessor :range
  attr_accessor :units

  def initialize(json_input)
    parsed = JSON.parse(json_input)
    @wanted_value = parsed['temperature']
    @range = parsed['range'] / 2.0
    @unit = parsed['unit']
  end

  # Update the thermostat

  def update(json_input)
    parsed = JSON.parse(json_input)
    @current_value = parsed['temperature']
    @unit_updated = parsed['unit']
    unit_updated
    unit
    check
  end

  # Update the unit

  def unit_updated
    @current_value = if @unit_updated == 'fahrenheit'
                       (@current_value - 32.0) / 1.8
                     elsif @unit_updated == 'kelvin'
                       (@current_value - 273.15)
                     elsif @unit_updated == 'celsius'
                       @current_value
                     else
                       @current_value
                     end
  end

  # Calculate the unit

  def unit
    @wanted_value = if @unit == 'fahrenheit'
                      (@wanted_value - 32.0) / 1.8
                    elsif @unit == 'kelvin'
                      (@wanted_value - 273.15)
                    elsif @unit == 'celsius'
                      @wanted_value
                    else
                      @wanted_value
                    end
  end

  # Check if it's to hot or to cold

  def check
    if @current_value < @wanted_value - @range
      heating
    elsif @current_value > @wanted_value + @range
      airco
    else
      normal
    end
  end

  # Display airco

  def airco
    '{"cooling":true,"heating":false}'
  end

  # Display heating

  def heating
    '{"cooling":false,"heating":true}'
  end

  # Display when it's normal

  def normal
    '{"cooling":false,"heating":false}'
  end
end
